@@ -1,4 +1,4 @@
-/* $Id: thread.cpp 127855 2019-01-01 01:45:53Z bird $ */
+/* $Id: thread.cpp 136784 2020-04-01 12:21:49Z bird $ */
 /** @file
  * IPRT - Threads, common routines.
  */
@@ -657,12 +657,14 @@ DECLHIDDEN(void) rtThreadTerminate(PRTTHREADINT pThread, int rc)
 {
     Assert(pThread->cRefs >= 1);
 
-#ifdef IPRT_WITH_GENERIC_TLS
     /*
      * Destroy TLS entries.
      */
+#ifdef IPRT_WITH_GENERIC_TLS
     rtThreadTlsDestruction(pThread);
-#endif /* IPRT_WITH_GENERIC_TLS */
+#elif defined(RT_OS_WINDOWS) && defined(IN_RING3)
+    rtThreadWinTlsDestruction();
+#endif
 
     /*
      * Set the rc, mark it terminated and signal anyone waiting.
