@@ -1,10 +1,10 @@
-/* $Id: assert.h 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: assert.h 127888 2019-01-01 06:31:29Z bird $ */
 /** @file
  * IPRT - Internal RTAssert header
  */
 
 /*
- * Copyright (C) 2009-2017 Oracle Corporation
+ * Copyright (C) 2009-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -24,8 +24,11 @@
  * terms and conditions of either the GPL or the CDDL or both.
  */
 
-#ifndef ___internal_assert_h
-#define ___internal_assert_h
+#ifndef IPRT_INCLUDED_INTERNAL_assert_h
+#define IPRT_INCLUDED_INTERNAL_assert_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 #include <iprt/types.h>
 
@@ -59,5 +62,5 @@ DECLHIDDEN(void) rtR0AssertNativeMsg2V(bool fInitial, const char *pszFormat, va_
 
 RT_C_DECLS_END
 
-#endif
+#endif /* !IPRT_INCLUDED_INTERNAL_assert_h */
 
