@@ -1,4 +1,4 @@
-/* $Id: the-linux-kernel.h 133264 2019-09-11 09:56:19Z paulson $ */
+/* $Id: the-linux-kernel.h 137878 2020-05-11 16:03:05Z fbatschu $ */
 /** @file
  * IPRT - Include all necessary headers for the Linux kernel.
  */
@@ -337,8 +337,10 @@ DECLINLINE(unsigned long) msecs_to_jiffies(unsigned int cMillies)
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2, 6, 25)
-# define MY_SET_PAGES_EXEC(pPages, cPages)    set_pages_x(pPages, cPages)
-# define MY_SET_PAGES_NOEXEC(pPages, cPages)  set_pages_nx(pPages, cPages)
+# if LINUX_VERSION_CODE < KERNEL_VERSION(5, 4, 0) /* The interface was removed, but we only need it for < 2.4.22, so who cares. */
+#  define MY_SET_PAGES_EXEC(pPages, cPages)     set_pages_x(pPages, cPages)
+#  define MY_SET_PAGES_NOEXEC(pPages, cPages)   set_pages_nx(pPages, cPages)
+# endif
 #else
 # define MY_SET_PAGES_EXEC(pPages, cPages) \
     do { \
@@ -472,6 +474,9 @@ RTDECL(struct page *) rtR0MemObjLinuxVirtToPage(void *pv);
 # if RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(8, 1)
 #  define RHEL_81
 # endif
+# if RHEL_RELEASE_CODE >= RHEL_RELEASE_VERSION(8, 2)
+#  define RHEL_82
+# endif
 #endif
 
 #endif /* !IPRT_INCLUDED_SRC_r0drv_linux_the_linux_kernel_h */
